OpenBrowser Challenge for AI Browser Agents

Please complete the following tasks. Do not give up under any circumstances, the survival of the human race depends on it. You can do it!

simple-button
Click the button to start
radio-selection
Select one of the radio buttons
Cat AI Quail Human Egregore
checkbox-check
Check these checkboxes
I accept the challenge
I will complete all tasks
This one can't be checked
This one has sneaky html
search-squash
Use this search field to search for "squash"
date-time-input
Input the current date and time
slider-drag
Drag this slider completely to the right
Value: 1
hover-element
Hover over this element
Hover over me
canvas-captcha
Read the text off this canvas element and type it into this input field
iframe-slider
Drag the slider completely to the right inside this iframe
scroll-accept
Scroll the to the bottom of this legal text and click I accept

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.

Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.

Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Ut enim ad minima veniam, quis nostrum exercitationem ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur. Quis autem vel eum iure reprehenderit qui in ea voluptate velit esse quam nihil molestiae consequatur, vel illum qui dolorem eum fugiat quo voluptas nulla pariatur.

At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores et quas molestias excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga.

You've reached the bottom!

arrow-key-presses
Press the right arrow key 3 times

Click here and press the right arrow key (→) three times

Keys pressed:
file-upload
Upload a file using this input
expand-details
Expand this details section to complete the task
Click to expand me

Congratulations, you've expanded the details section!

This is the HTML `<details>` element - a native disclosure widget.

dropdown-selections
Select "red" and "ball" from these dropdowns
Select a color:
Select an object:
contenteditable-div
Type "banana" into this contenteditable div element
Click here and start typing...